.. RNAlysis documentation master file, created by
   sphinx-quickstart on Thu Jul  4 20:06:55 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to RNAlysis's documentation!
===============================================
GitHub page:
https://github.com/GuyTeichman/RNAlysis

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   usage
   rnalysis_user_guide
   contributing
   authors
   history

Individual Modules
==================

.. autosummary::
  :toctree:

  rnalysis.filtering
  rnalysis.enrichment
  rnalysis.general
  rnalysis.feature_name_to_wbgene



Alphabetical index
==================

* :ref:`genindex`



All documentation
=================

.. toctree::
   :maxdepth: 2

   rnalysis
